@@ -463,9 +463,7 @@ class IQ_Option:
                 if self.api.candles.candles_data != None:
                     break
         except Exception as e:
-            logging.error('**error** get_candles need reconnect: ')
             logging.error(e)
-            raise ConnectionError()
 
         return self.api.candles.candles_data
 
